// const fs = require('fs');
// const path = require('path');


// const jsonDataPath = path.join(__dirname, 'data.json');
// const jsonData = require(jsonDataPath);


// const templateContent = generateTemplate(jsonData);


// const componentCode = `
// <template>
//   ${templateContent}
// </template>

// <script>
// export default {
//   data() {
//     return {
      
//     };
//   }
// };
// </script>

// <style scoped>

// </style>
// `;


// const outputFilePath = path.join(__dirname, 'GeneratedComponent.vue');
// fs.writeFileSync(outputFilePath, componentCode);

// console.log(`Vue component generated successfully at ${outputFilePath}`);

// function generateTemplate(jsonData) {
 
//   function generateTemplateRecursive(data) {
//     if (typeof data === 'string') {
//       return data;
//     } else if (Array.isArray(data)) {
//       return data.map(generateTemplateRecursive).join('\n');
//     } else if (typeof data === 'object') {
//       const tagName = data.tagName || 'div';
//       const properties = data.properties
//         ? ' ' + Object.entries(data.properties)
//             .map(([key, value]) => `${key}="${value}"`)
//             .join(' ')
//         : '';

//       const directives = [];
//       if (data.vIf && shouldIncludeDirective(data.vIf)) {
//         directives.push(`v-if="${data.vIf}"`);
//       }
//       if (data.vShow && shouldIncludeDirective(data.vShow)) {
//         directives.push(`v-show="${data.vShow}"`);
//       }
//       if (data.vFor && shouldIncludeDirective(data.vFor)) {
//         directives.push(`v-for="${data.vFor}"`);
//       }

//       const directiveString = directives.length > 0 ? ` ${directives.join(' ')}` : '';
//       const children = data.children ? generateTemplateRecursive(data.children) : '';

//       return `<${tagName}${properties}${directiveString}>${children}</${tagName}>`;
//     } else {
//       return String(data);
//     }
//   }

//   function shouldIncludeDirective(directive) {
    
//     return true;
//   }

//   return `${generateTemplateRecursive(jsonData)}`;
// }


















const fs = require('fs');
const path = require('path');

const jsonDataPath = path.join(__dirname, 'data.json');
const jsonData = require(jsonDataPath);

const { templateContent, scriptContent } = generateTemplate(jsonData);

const componentCode = `
<template>
  ${templateContent}
</template>

<script>
${scriptContent}
</script>

<style scoped>

</style>
`;

const outputFilePath = path.join(__dirname, 'GeneratedComponent.vue');
fs.writeFileSync(outputFilePath, componentCode);

console.log(`Vue component generated successfully at ${outputFilePath}`);

function generateTemplate(jsonData) {
 
  function generateTemplateRecursive(data) {
    if (typeof data === 'string') {
      return data;
    } else if (Array.isArray(data)) {
      return data.map(generateTemplateRecursive).join('\n');
    } else if (typeof data === 'object') {
      const tagName = data.tagName || 'div';
      const properties = data.properties
        ? ' ' + Object.entries(data.properties)
            .map(([key, value]) => `${key}="${value}"`)
            .join(' ')
        : '';

      const directives = [];
      if (data.vIf && shouldIncludeDirective(data.vIf)) {
        directives.push(`v-if="${data.vIf}"`);
      }
      if (data.vShow && shouldIncludeDirective(data.vShow)) {
        directives.push(`v-show="${data.vShow}"`);
      }
      if (data.vFor && shouldIncludeDirective(data.vFor)) {
        directives.push(`v-for="${data.vFor}"`);
      }

      const directiveString = directives.length > 0 ? ` ${directives.join(' ')}` : '';
      const children = data.children ? generateTemplateRecursive(data.children) : '';

      return `<${tagName}${properties}${directiveString}>${children}</${tagName}>`;
    } else {
      return String(data);
    }
  }

  function shouldIncludeDirective(directive) {
    
    return true;
  }

  function generateScriptContent(data) {
    let scriptData = `export default {\n  data() {\n`;
  
    function processScriptProperties(data) {
      if (typeof data === 'object') {
        scriptData += '    return {\n';
  
        if (data.children) {
          data.children.forEach(child => {
            if (child.properties && typeof child.properties === 'object') {
              Object.entries(child.properties).forEach(([key, value]) => {
                if (!scriptData.includes(`${key}:`)) {
                  scriptData += `      ${key}: ${JSON.stringify(value)},\n`;
                }
              });
            }
          });
        }
  
        Object.entries(data).forEach(([key, value]) => {
          if (key === 'children') {
            scriptData += `      ${key}: ${generateChildrenScript(value)},\n`;
          } else {
            if (!scriptData.includes(`${key}:`)) {
              scriptData += `      ${key}: ${JSON.stringify(value)},\n`;
            }
          }
        });
  
        scriptData += '    };\n';
      } else {
        scriptData += `    return ${JSON.stringify(data)};\n`;
      }
    }
  
    function generateChildrenScript(children) {
      if (Array.isArray(children)) {
        const processedChildren = children.map(child => processScriptProperties(child)).join(',\n');
        return `[\n${processedChildren}\n]`;
      } else {
        return '[]';
      }
    }
  
    processScriptProperties(data);
  
    scriptData += '  }\n};\n';
    return scriptData;
  }
  
  
  
  

  return {
    templateContent: generateTemplateRecursive(jsonData),
    scriptContent: generateScriptContent(jsonData),
  };
}
